@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP::Client;
 use vars '$VERSION';
-$VERSION = '0.68';
+$VERSION = '0.69';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
 
@@ -53,6 +53,16 @@ sub compileClient(@)
     my $transport = $args{transport}
         or error __x"transport for client {name} required", name => $name;
 
+    if(ref $transport eq 'CODE') { ; }
+    elsif(UNIVERSAL::isa($transport, 'XML::Compile::Transport::SOAPHTTP'))
+    {   $transport = $transport->compileClient;
+    }
+    else
+    {   error __x"transport for client {name} is code ref or {type} object, not {is}"
+          , name => $name, type => 'XML::Compile::Transport::SOAPHTTP'
+          , is => (ref $transport || $transport);
+    }
+
     my $core = sub
     {   my $start = time;
         my ($data, $charset) = UNIVERSAL::isa($_[0], 'HASH') ? @_ : ({@_});
@@ -67,15 +77,17 @@ sub compileClient(@)
         $trace{start}  = $start;
         $trace{encode_elapse} = $trace{transport_start} - $start;
 
-        UNIVERSAL::isa($ans, 'XML::LibXML::Node')
-            or return ($ans, \%trace);
+        if(UNIVERSAL::isa($ans, 'XML::LibXML::Node'))
+        {   $ans = $decode->($ans);
+            my $end = time;
+            $trace{decode_elapse} = $end - $trace{transport_end};
+            $trace{elapse} = $end - $start;
+        }
+        else
+        {   $trace{elapse} = $trace{transport_end} - $start;
+        }
 
-        my $dec = $decode->($ans);
-        my $end = time;
-        $trace{decode_elapse} = $end - $trace{transport_end};
-        $trace{elapse} = $end - $start;
-
-        ($dec, XML::Compile::SOAP::Trace->new(\%trace));
+        ($ans, XML::Compile::SOAP::Trace->new(\%trace));
     };
 
     # Outgoing messages
