@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP;  #!!!
 use vars '$VERSION';
-$VERSION = '0.68';
+$VERSION = '0.69';
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
 use List::Util qw/min first/;
@@ -517,7 +517,7 @@ sub _dec_soapenc($$)
 {   my ($self, $node, $type) = @_;
     my $read = $self->_dec_reader($type)
        or return $node;
-    my $data = ($read->($node))[1];
+    my $data = $read->($node);
     $data = { _ => $data } if ref $data ne 'HASH';
     $data->{_TYPE} = $type;
     $data;
